Checkpointer

Struct Checkpointer 

pub struct Checkpointer<'a, W: OutputWriter, R: InputReader> { /* private fields */ }

Implementations

Source

impl<'a, W: OutputWriter, R: InputReader> Checkpointer<'a, W, R>

pub fn checkpoint( &mut self, sequence_number: Option<String>, sub_sequence_number: Option<u64>, ) -> Result<(), CheckpointError>

Checkpoints at a particular sequence number you provide or if no sequence number is given, the checkpoint will be at the end of the most recently delivered list of records.

Arguments
  • sequence_number: the sequence number to checkpoint
  • sub_sequence_number: the sub sequence number generated by KPL

returns: Result<(), Report>

Examples found in repository?
examples/example_consumer/main.rs (line 29)
17    fn process_records(
18        &mut self,
19        data: &[Record],
20        checkpointer: &mut Checkpointer<StdoutWriter, StdinReader>,
21    ) {
22        for record in data {
23            match record.json::<MyPayload>() {
24                Ok(data) => println!("{:?}", data.event_field),
25                Err(e) => println!("{:?}", e),
26            }
27        }
28        checkpointer
29            .checkpoint(None, None)
30            .expect("Checkpoint to succeed.");
31    }
32    fn lease_lost(&mut self) {}
33    fn shard_ended(&mut self, checkpointer: &mut Checkpointer<StdoutWriter, StdinReader>) {
34        checkpointer
35            .checkpoint(None, None)
36            .expect("Checkpoint to succeed.");
37    }
38    fn shutdown_requested(&mut self, checkpointer: &mut Checkpointer<StdoutWriter, StdinReader>) {
39        checkpointer
40            .checkpoint(None, None)
41            .expect("Checkpoint to succeed.");
42    }